%% Doing Economics with the Computer
% *Lecture 4: SOLUTIONS* $\\$
% Harris Dellas $\\$
% Lucas Kyriacou

%% Matlab Application: Financial Evaluation 1
% In this lecture we will explain how to use MATLAB to solve 
% amortization problems, interest compounding and defaulting on a mortgage.  

%% Compulsory Readings
% Up to now, you should have read chapters 1 - 6 in Attaway (2019). The book is provided on Ilias. 

%% Further Exercises
% Up to now, you should have solved the practice questions in chapters 1 - 6 in Attaway (2019). 
% Solutions to the practice questions in chapter 3-6 are available on Ilias.

%% Housekeeping
% When you write a script, you should include these commands at the start.

clear all % Deletes memory
close all % closes open windows (figures etc.)
clc       % clears command window 


%% Number format
% Change number format
format bank % Format numbers in currency format with 2 digits after the decimal point

%% Fixed Rate Mortgage Payments
% Let us consider a fixed rate mortgage, that is, a mortgage that carries a 
% fixed interest rate over its lifetime.  We would like to understand how 
% mortgage payments relate to the initial amount and the evolution of 
% the principal, and the role of the interest rate and the length of the 
% loan period. Let us assume that payments are made monthly until the 
% principal has been paid out and that all the payments are of the same size.

%% Definitions
% * $T =$  maturity of loans (number of years) 
% * $N =T*12=$ total number of payments
% * $n =$ is number of payment
% * $p(t) =$ principal, $t=1, 2, ...,N$, 
% * $A =$ initial principal 
% * $R =$ constant, monthly payment
% * $ra =$ annual interest rate
% * $r =ra/12=$ monthly interest rate

%% Example:
% A 20-year loan of size $A= 350000$, at an annual interest of $ra=0.05$, that is $5\%$. 
% The principal then evolves according to $p(n+1)=(1+r)p(n) - R$.
% We can write the principal on the final date as (see table) $\\\\$
% $p(N)=A*(1+r)^N-R*\sum_{j=0}^{N-1} (1+r)^j$. $\\\\$
% The principal on the final date must be zero (the loan will have been fully repaid), 
% that is $p(N)=0$. Using this and solving for R 
% (utilizing the definition of the sum of a finite geometric series) gives
% the required amount of monthly  payment R: $\\\\$
% $R= \frac{r*A*(1+r)^N}{(1+r)^N-1}$.

% \input{Table1}

%% Exercises:
%% A. Fixed Rate Mortgage Payments
%% a) 
% Suppose that $T=30, ra=0.05, A=400000$. Using MATLAB determine the required monthly payments R. 
% How much principal is left after 10 years? After 20 years? 
% Use a for loop to answer the latter questions. 
% Do it both on line (i.e. 'in script form') and using a function file.

%% a.i) Script form

% YOUR CODE HERE!

%% a.ii) Function file
% Write the function file, pay.m that calculates the required monthly payments and the principal for each month. 
% Give the parameter values from above and call the function. The result
% should be the same as in a.i). 

% YOUR CODE HERE!

%% b) 
% Let the annual interest rate now be higher, namely 0.06 and answer part (a) with the function file pay.m.

% YOUR CODE HERE!


%% c) 
% Suppose that given your income, you can afford to make a maximum monthly payment $R=500$. 
% If the annual interest rate is $ra=0.05$ what is the maximum amount of a 20 year loan that you can afford to borrow? Of a 30 year loan?

%% c.i) Using a script file: 20 year loan

% YOUR CODE HERE!

%% c.i) Using a script file: 30 year loan

% YOUR CODE HERE!


%% c.ii) Using a function file: 30 year loan

% YOUR CODE HERE!

%% d)
% Suppose that you have an arrangement that during the first 5 years of the 30 year
% mortgage of 400'000 you only have to pay the interest due and nothing of the capital. 
% What is the monthly payment you will have to make over the remaining 25 years? 
% Is it smaller or larger than if you did not have this deal? Compute the principal 
% after 10 years. Plot the evolution of the principal with and without the deal in the same graph.

% YOUR CODE HERE!

%% e) 
% Suppose now that you pay nothing during the first 5 years and then you pay 
% 500 over the following 5 years. What must the monthly payment R over the remaining 20 years 
% be in order for the mortgage to be fully repaid?

% YOUR CODE HERE!

%% e.i) 
% Suppose that the bank unexpectedly forgives the remaining amount of the loan once the 
% principal has fallen below 50000. After how many months will this happen?

% YOUR CODE HERE!

%% e.ii) 
% Find an alternative way to solve the task above (use a while loop)

% YOUR CODE HERE!

%% B. Flexible Rate Mortgage Payment
% Let us now consider a flexible, 30 year mortgage, that is, a mortgage
% for which the interest rate changes from one month to the next. 
% Let the monthly rate be r(n) and suppose, for simplicity, that the path of
% interest rates is known when the mortgage is issued and that the borrower
% still makes a fixed payment of 2000 every month.  At the end of the 30 years
% period, the borrower pays the balance to the creditor. How much is this balance?
% Let $T=30,  A=400000$ so that $N=360$, $R=2000$  and r be in the interval [a,b] of a uniform distribution, 
% $a=0.003,b=0.005$, so that  $r = a + (b-a)*rand(360,1)$.

%% Exercises:
%% B. Flexible Rate Mortgage Payments
%% a)  
% Using MATLAB determine the amount of principal left after: 10 years;  after 30 years.

% YOUR CODE HERE!

%% b.i) 
% Now suppose that in each period you pay the full interest cost plus one 
% tenth of the principal owed in that period. How much will you owe 
% after 5 years? How many months will it take you before your principal drops below 50000?

% YOUR CODE HERE!

%% b.ii) 
% Find an alternative way to solve the task above

% YOUR CODE HERE!